@@ -57,10 +57,6 @@ class PyccuracyCore(object):
         if not context:
             context = Context(settings)
 
-        context.on_before_action = kwargs.get('on_before_action', None)
-        context.on_action_successful = kwargs.get('on_action_successful', None)
-        context.on_action_error = kwargs.get('on_action_error', None)
-
         if not self.runner:
             self.runner = context.settings.worker_threads == 1 and StoryRunner() or ParallelStoryRunner(settings.worker_threads)
 
